@@ -7,17 +7,33 @@ import boto3
 import json
 import time
 from progress.bar import Bar
-import importlib
 import os
 
 init() #colorama
 
 class credentials:
-    def __init__(self, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, AWS_DEFAULT_REGION, repoURL):
+    def __init__(self, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, AWS_DEFAULT_REGION, repoURL=""):
         self.AWS_ACCESS_KEY_ID = AWS_ACCESS_KEY_ID
         self.AWS_SECRET_ACCESS_KEY = AWS_SECRET_ACCESS_KEY
         self.AWS_DEFAULT_REGION = AWS_DEFAULT_REGION
-        self.repo_URL = repoURL
+        self.repoURL = repoURL
+    def setRepoURL(self, repoURL):
+        self.repoURL = repoURL
+    def printRepoURL(self):
+        print(f"The HTTP clone URL for the repo: {Fore.YELLOW}{self.repoURL}{Style.RESET_ALL}")
+
+
+def createRepo(repoName, repoDesc, creds):
+    CC_client = boto3.client('codecommit', 
+                            region_name=creds.AWS_DEFAULT_REGION, 
+                            aws_access_key_id=creds.AWS_ACCESS_KEY_ID,
+                            aws_secret_access_key=creds.AWS_SECRET_ACCESS_KEY
+                            )
+    repoCreate_response = CC_client.create_repository(
+        repositoryName=repoName,
+        repositoryDescription=repoDesc
+    )
+    creds.setRepoURL(repoCreate_response['repositoryMetadata']['cloneUrlHttp'])
 
 
 def createCBRole(projName, creds):
@@ -127,8 +143,6 @@ def createCBRole(projName, creds):
     return IAMCreate_response['Role']['Arn']
 
 
-
-
 def createCB(projName, creds):
 
     ARN = createCBRole(projName, creds) #THIS IS THE MAIN ISSUE. it seems like AWS takes a bit of time to load the roles
@@ -212,7 +226,7 @@ def createSls(slsPath):
     service = input('Service Name: ')
     region = input('Region: ')
     stage = input('Stage: ')
-    sls = f'service: {service}\n\nframeworkVersion: \'2\'\n\nprovider:\n  name: aws\n  runtime: nodejs12.x\n  lambdaHashingVersion: 20201221\n  stage: {stage}\n  region: {region}\npackage:\n  individually: true\n\nfunctions:\n'
+    sls = f'service: {service}\n\nframeworkVersion: \'2\'\n\nprovider:\n  name: aws\n  runtime: nodejs12.x\n  lambdaHashingVersion: 20201221\n  stage: {stage}\n  region: {region}\n  package:\n    individually: true\n\nfunctions:\n'
     with open('serverless.yml', 'w') as fSls:
         fSls.write(sls)
         
@@ -248,27 +262,44 @@ def addToBSpec(env_name, allorOne, funName):
 @click.option('--buildspec', '-b')
 def main(skip, buildspec):
     print(f"{Fore.CYAN}========SLS Manager v 0.1.0========{Style.RESET_ALL}")
-    cbInput = input("Would you like to create a CodeBuild project? (Y/N): ")
-    if cbInput.lower() == 'y':
+    
+    ccInput = input("Would you like to create a new CodeCommit Repo? (Y/N): ")
+    if ccInput.lower() == 'y':
         AWS_ACCESS_KEY_ID = input('AWS ACCESS KEY ID: ')
         AWS_SECRET_ACCESS_KEY = input('AWS SECRET ACCESS KEY: ')
         AWS_DEFAULT_REGION = input('AWS DEFAULT REGION: ')
-        repoURL = input('CodeCommit Repository URL: ')
-        creds = credentials(AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, AWS_DEFAULT_REGION, repoURL)
+        repoName = input('CodeCommit Repository Name: ')
+        repoDesc = input('Repository description (Leave empty if blank): ')
+        creds = credentials(AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, AWS_DEFAULT_REGION)
+        createRepo(repoName, repoDesc, creds)
+        creds.printRepoURL()
+    
+    cbInput = input("Would you like to create a new CodeBuild project? (Y/N): ")
+    if cbInput.lower() == 'y':
+        if ccInput.lower() != 'y':
+            AWS_ACCESS_KEY_ID = input('AWS ACCESS KEY ID: ')
+            AWS_SECRET_ACCESS_KEY = input('AWS SECRET ACCESS KEY: ')
+            AWS_DEFAULT_REGION = input('AWS DEFAULT REGION: ')
+            repoURL = input('CodeCommit Repository URL: ')
+            creds = credentials(AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, AWS_DEFAULT_REGION, repoURL)
         projName = input("Name of CodeBuild project: ")
         createCB(projName, creds)
+
     slsPath = Path('serverless.yml')
     if not slsPath.exists():
         createSls(slsPath)
+    
     env_name = input(f"ENV_NAME: ")
     module = input("Name of Module (Eg: handler.firstFun): ")
     funName = input("Name of Function: ")
     fName = module.split('.')[0] + '.js'
     mName = module.split('.')[1]
     fPath = Path(fName)
+
     if skip == 1:
         print(f"{Fore.YELLOW}Skipping Checks")
         print(f"{Fore.GREEN}OK! Adding {module} to serverless.yml{Style.RESET_ALL}\n")
+    
     else:
         if fPath.exists():
             with open(fName) as fin:
@@ -281,12 +312,13 @@ def main(skip, buildspec):
             print(f"{Fore.RED}Path {fName} does not exist! \n{Fore.YELLOW}If you still want to add it, run program with -s or --skip{Style.RESET_ALL}")
             return
     
-    
     addTosls(fName, module, funName)
     print(f"If you want to add more properties, \n{Fore.YELLOW}visit: https://www.serverless.com/framework/docs/providers/aws/guide/serverless.yml/{Style.RESET_ALL}\n")
     print(f"{Fore.YELLOW}If you would like to add more files (Other than '{fName}') to the lambda function, edit serverless.yml and add the required files to the \'package\' section under your newly added function.{Style.RESET_ALL}\n")
     print(f"{Fore.GREEN}Adding {env_name} to buildspec.yml.{Style.RESET_ALL} \nCheck Environment Variable config here: LINK")
+    
     allorOne = input(f"Press A if you would like to deploy all lambda functions in repo (N otherwise): ")
+    
     addToBSpec(env_name, allorOne, funName)
     
 
